claviger Changelog
******************

0.1.2 (2016-01-08)
==================

- Show the correct number of keys actually removed.


0.1.1 (2015-12-21)
==================

- Some cosmetic changes.
- Show example configuration file, if claviger isn't configured yet.
- Python 3 compatibility.

0.1.0 (2015-12-14)
==================

- Initial release.
